;Inputs:
;---------------
;BX: Value bits to select mono or color port:
;                   --
;          0000000001000000b -- color (produce 0x3DA)
;          0000000000100000b -- mono  (produce 0x3BA)
;                   --
;
;ESI == Base address of the register set
;;
VGA_Config_All_Regs:
pushawide
pushfwide


mov ah,00100000b  ;Turn monitor off
call VGA_Sequencer_Monitor_OnOff


;Set the registers counter to 0:
;;
  xor ecx,ecx



;Write Miscellaneous Output Register:
;;
  mov dx,0x3C2    ;Point to the register
  lodsb           ;Load the byte value
  out dx,al       ;Set the register


;INIT: 0x3DA or 0x3BA
;INIT: 0x3DA or 0x3BA
;INIT: 0x3DA or 0x3BA
;Apply the selection value for the color/mono register.
;This will complete the value for 0x3DA or 0x3BA,
;respectively:
;;
  mov dx,0x39A    ;Point to the register
  ;or dx,bx
  or dl,bl
;END:  0x3DA or 0x3BA
;END:  0x3DA or 0x3BA
;END:  0x3DA or 0x3BA
  lodsb           ;Load the byte value

;Write Feature Control Register:
;;
  out dx,al       ;Set the register




;Write Sequencer Registers:
;;
  mov dx,0x3C4             ;Point to the Sequencer
  mov cl,5                 ;Load the number of Sequencer registers to write
  call VGA_write_indexed_registers_WORD  ;Write all registers
 
 
;Write CRTC Registers:
;;
  mov dx,0x3D4    ;Point to the CRTC

  xor eax,eax              ;First unprotect CRTC regs 0-7
  call VGA_protect_unprotect_CRTC_regs

  mov cl,25                ;Load the number of CRTC registers to write
  call VGA_write_indexed_registers_WORD  ;Write all registers


;Write Graphics Controller Registers:
;;
  mov dx,0x3CE             ;Point to the Graphics Controller
  mov cl,9                 ;Load the number of Graphics registers to write
  call VGA_write_indexed_registers_WORD  ;Write all registers


;INIT: 0x3DA or 0x3BA
;INIT: 0x3DA or 0x3BA
;INIT: 0x3DA or 0x3BA
;Apply the selection value for the color/mono register.
;This will complete the value for 0x3DA or 0x3BA,
;respectively:
;;
  mov dx,0x39A    ;Point to the register
  ;or dx,bx
  or dl,bl
;END:  0x3DA or 0x3BA
;END:  0x3DA or 0x3BA
;END:  0x3DA or 0x3BA
  in al,dx    ;First reset the flip/flop
              ;by reading port 0x3DA

;Write Attribute Control Registers:
;;
  mov dx,0x3C0             ;Point to the Attribute Controller
  mov cl,21                ;Load the number of Attribute registers to write
  call VGA_write_indexed_registers_BYTE  ;Write all registers


;INIT: 0x3DA or 0x3BA
;INIT: 0x3DA or 0x3BA
;INIT: 0x3DA or 0x3BA
;Apply the selection value for the color/mono register.
;This will complete the value for 0x3DA or 0x3BA,
;respectively:
;;
  mov dx,0x39A    ;Point to the register
  ;or dx,bx
  or dl,bl
;END:  0x3DA or 0x3BA
;END:  0x3DA or 0x3BA
;END:  0x3DA or 0x3BA
  in al,dx    ;Reset the flip/flop again
              ;for full safety that this controller
              ;will be well aligned for future accesses


;We need to enable access to the palette because
;the standard way to program the Attribute Controller
;requires disabling access to it and then enable it,
;since it is also located in the Attribute Controller's
;index register:
;;
  call VGA_Attribute_Controller__EnablePalette

  mov bx,11011111b  ;Turn monitor on
  call VGA_Sequencer_Monitor_OnOff




;INIT: 0x3DA or 0x3BA
;INIT: 0x3DA or 0x3BA
;INIT: 0x3DA or 0x3BA
;Read Feature Control Register:
;Apply the selection value for the color/mono register.
;This will complete the value for 0x3DA or 0x3BA,
;respectively:
;;
  mov dx,0x39A    ;Point to the register
  ;or dx,bx
  or dl,bl

;END:  0x3DA or 0x3BA
;END:  0x3DA or 0x3BA
;END:  0x3DA or 0x3BA
  in al,dx    ;Reset the flip/flop again
              ;for full safety that this controller
              ;will be well aligned for future accesses



;We have finished!
;;


 popfwide
popawide
retwide




;EOF